@@ -1,17 +1,15 @@
 //! Request logging middleware
-use std::fmt::{self, Display};
 use std::task::{Context, Poll};
 use std::{convert::TryFrom, env, error::Error, future::Future, pin::Pin, rc::Rc, time};
+use std::{fmt, fmt::Display, marker::PhantomData};
 
-use bytes::Bytes;
 use regex::Regex;
 
 use crate::http::body::{Body, BodySize, MessageBody, ResponseBody};
 use crate::http::header::HeaderName;
 use crate::service::{Service, Transform};
-use crate::util::{Either, HashSet, Ready};
-use crate::web::dev::{WebRequest, WebResponse};
-use crate::web::HttpResponse;
+use crate::util::{Bytes, Either, HashSet};
+use crate::web::{HttpResponse, WebRequest, WebResponse};
 
 /// `Middleware` for logging request and response info to the terminal.
 ///
@@ -115,22 +113,14 @@ impl Default for Logger {
     }
 }
 
-impl<S, Err> Transform<S> for Logger
-where
-    S: Service<Request = WebRequest<Err>, Response = WebResponse>,
-{
-    type Request = WebRequest<Err>;
-    type Response = WebResponse;
-    type Error = S::Error;
-    type InitError = ();
-    type Transform = LoggerMiddleware<S>;
-    type Future = Ready<Self::Transform, Self::InitError>;
+impl<S> Transform<S> for Logger {
+    type Service = LoggerMiddleware<S>;
 
-    fn new_transform(&self, service: S) -> Self::Future {
-        Ready::Ok(LoggerMiddleware {
+    fn new_transform(&self, service: S) -> Self::Service {
+        LoggerMiddleware {
             service,
             inner: self.inner.clone(),
-        })
+        }
     }
 }
 
@@ -140,14 +130,13 @@ pub struct LoggerMiddleware<S> {
     service: S,
 }
 
-impl<S, E> Service for LoggerMiddleware<S>
+impl<S, E> Service<WebRequest<E>> for LoggerMiddleware<S>
 where
-    S: Service<Request = WebRequest<E>, Response = WebResponse>,
+    S: Service<WebRequest<E>, Response = WebResponse>,
 {
-    type Request = WebRequest<E>;
     type Response = WebResponse;
     type Error = S::Error;
-    type Future = Either<LoggerResponse<S>, S::Future>;
+    type Future = Either<LoggerResponse<S, E>, S::Future>;
 
     #[inline]
     fn poll_ready(&self, cx: &mut Context<'_>) -> Poll<Result<(), Self::Error>> {
@@ -174,6 +163,7 @@ where
                 time,
                 format: Some(format),
                 fut: self.service.call(req),
+                _t: PhantomData,
             })
         }
     }
@@ -181,18 +171,19 @@ where
 
 pin_project_lite::pin_project! {
     #[doc(hidden)]
-    pub struct LoggerResponse<S: Service>
+    pub struct LoggerResponse<S: Service<WebRequest<E>>, E>
     {
         #[pin]
         fut: S::Future,
         time: time::SystemTime,
         format: Option<Format>,
+        _t: PhantomData<E>
     }
 }
 
-impl<S, E> Future for LoggerResponse<S>
+impl<S, E> Future for LoggerResponse<S, E>
 where
-    S: Service<Request = WebRequest<E>, Response = WebResponse>,
+    S: Service<WebRequest<E>, Response = WebResponse>,
 {
     type Output = Result<WebResponse, S::Error>;
 
@@ -467,7 +458,7 @@ impl<'a> fmt::Display for FormatDisplay<'a> {
 mod tests {
     use super::*;
     use crate::http::{header, StatusCode};
-    use crate::service::{IntoService, Service, Transform};
+    use crate::service::{IntoService, Transform};
     use crate::util::lazy;
     use crate::web::test::{self, TestRequest};
     use crate::web::{DefaultError, Error};
@@ -487,10 +478,7 @@ mod tests {
         let logger = Logger::new("%% %{User-Agent}i %{X-Test}o %{HOME}e %D %% test")
             .exclude("/test");
 
-        let srv = Transform::new_transform(&logger, srv.into_service())
-            .await
-            .unwrap();
-
+        let srv = Transform::new_transform(&logger, srv.into_service());
         assert!(lazy(|cx| srv.poll_ready(cx).is_ready()).await);
         assert!(lazy(|cx| srv.poll_shutdown(cx, true).is_ready()).await);
 
